@@ -2,7 +2,7 @@ package Plack::Session::State::Cookie;
 use strict;
 use warnings;
 
-our $VERSION   = '0.33';
+our $VERSION   = '0.34';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use parent 'Plack::Session::State';
@@ -16,6 +16,7 @@ use Plack::Util::Accessor qw[
     secure
     httponly
     samesite
+    partitioned
 ];
 
 sub get_session_id {
@@ -28,17 +29,25 @@ sub merge_options {
 
     delete $options{id};
 
-    $options{path}     = $self->path || '/' if !exists $options{path};
-    $options{domain}   = $self->domain      if !exists $options{domain} && defined $self->domain;
-    $options{secure}   = $self->secure      if !exists $options{secure} && defined $self->secure;
-    $options{httponly} = $self->httponly    if !exists $options{httponly} && defined $self->httponly;
-    $options{samesite} = $self->samesite    if !exists $options{samesite} && defined $self->samesite;
+    $options{path}        = $self->path || '/' if !exists $options{path};
+    $options{domain}      = $self->domain      if !exists $options{domain} && defined $self->domain;
+    $options{secure}      = $self->secure      if !exists $options{secure} && defined $self->secure;
+    $options{httponly}    = $self->httponly    if !exists $options{httponly} && defined $self->httponly;
+    $options{samesite}    = $self->samesite    if !exists $options{samesite} && defined $self->samesite;
+
+    # https://developer.mozilla.org/en-US/docs/Web/Privacy/Privacy_sandbox/Partitioned_cookies
+    $options{partitioned} = $self->partitioned if !exists $options{partitioned} && defined $self->partitioned;
 
 
     if (!exists $options{expires} && defined $self->expires) {
         $options{expires} = time + $self->expires;
     }
 
+    if ($options{partitioned}) {
+        $options{secure} = 1;
+        $options{samesite} = 'None';
+    }
+
     return %options;
 }
 
@@ -57,10 +66,10 @@ sub finalize {
 sub _set_cookie {
     my($self, $id, $res, %options) = @_;
 
-    my $cookie = bake_cookie( 
+    my $cookie = bake_cookie(
         $self->session_key, {
             value => $id,
-            %options,            
+            %options,
         }
     );
     Plack::Util::header_push($res->[1], 'Set-Cookie', $cookie);
@@ -131,6 +140,11 @@ be included in the cookie.
 HttpOnly flag for the cookie, if nothing is supplied then it will not
 be included in the cookie.
 
+=item B<samesite>
+
+SameSite flag for the cookie, if nothing is supplied then it will not
+be included in the cookie.
+
 =back
 
 =head1 BUGS
